@@ -8,8 +8,12 @@ deparse_spc <- function(x){
   z <- character(length = length(x))
   for (i in seq_along(x)){
     if (length(x[[i]]) > 1){
+      str <- paste(x[[i]], collapse = " ")
+      if (nchar(str) > 115){  # strings should be no longer than 130 
+        str <- paste(strwrap(str, width = 115), collapse = "\n  ")
+      }
       # put brackets around several elements
-      z[i] <- paste0("  ", nx[i], " = (", paste(x[[i]], collapse = " "), ")")
+      z[i] <- paste0("  ", nx[i], " = (", str, ")")
     } else if (length(x[[i]] == 1)){
       # put brackets around elements containing a comma
       if (grepl(',', x[[i]])){
